@@ -1,4 +1,4 @@
-// $Id: observer_thread.c,v 1.1.1.1 2005/11/04 09:07:01 khlut Exp $
+// $Id: observer_thread.c,v 1.2 2006/02/03 21:43:08 khlut Exp $
 // Copyright 2005 Elphel, Inc.
 //
 // This file is part of GenReS.
@@ -23,7 +23,7 @@
 #include <sys/socket.h>
 #include <errno.h>
 
-int run_slave( PD * pd, char * mime ) // this function is not in observer thread, it run a separate parallel process
+int run_slave( PD * pd, char * mime, int restart ) // this function is not in observer thread, it run a separate parallel process
 {
     int p[2]={-1,-1};
     char *path = find_slave(mime);
@@ -37,9 +37,10 @@ int run_slave( PD * pd, char * mime ) // this function is not in observer thread
 	dup2(p[1],1);
 	dup2(p[1],2);
 	close(p[1]);
-	execl(path,path,0);
+	if(restart) execl(path,path,"--no-vars",0);
+	else execl(path,path,0);
 	perror("error");
-	printf("errorfile=%s\n",path);	
+	printf("errorfile=%s\n",path);
 	printf("run=0\n");	
 	_exit(1);
     }
